import datetime
import os

from MidiFile import MIDIFile


def midi(part_list, tempo, path):

    # create MIDI file object
    track_count = len(part_list)
    midi_file = MIDIFile(track_count)
    # add data
    time = 0.0
    for part in part_list:
        # set up track
        midi_file.addTempo(part.track, time, tempo)
        midi_file.addTrackName(part.track, time, "Track " + str(part.track))
        midi_file.addProgramChange(part.track, part.channel, time,
                                   part.instrument)
        # add note(s)
        note_list = []
        for fragment in part.fragment_list:
            note_list += fragment.flat()
        for note in note_list:
            midi_file.addNote(part.track,
                              part.channel,
                              note.pitch,
                              note.onset,
                              note.duration,
                              note.intensity)
    # write file
    if path is None:
        # construct default path
        filename = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
        filename += ".mid"
        path = os.path.join(os.path.expanduser("~"), filename)
    f = open(path, "wb")
    midi_file.writeFile(f)
    # clean up
    f.close()
